Founders
========

* Heiko 'riot' Weinen (riot@c-base.org, @__r107__, ri0t@github)
* Johannes 'ijon' Rundfeldt (ijon@c-base.org, @aegrereminiscen, ij0n@github)

Meet us at c-base, the spacestation below Berlin Mitte!
